searchData={"items":[{"type":"module","title":"ExAws.Support","doc":"Operations for AWS Support API\n\nThe documentation and types provided lean heavily on the [AWS documentation for\nAWS Support](https://docs.aws.amazon.com/awssupport/latest/APIReference/API_Operations.html).\nThe AWS documentation is the definitive source of information and should be consulted to\nunderstand how to use AWS Support and its API functions. The documentation on types and\nfunctions in the library may be helpful but it is merely helpful. It does not attempt to\nprovide an explanation for how to use AWS Support.\n\nThe library does not try to provide protection against invalid values, length restriction\nviolations, or violations of pattern matching defined in the API documentation. There is some\nminimal checking for correct types but, generally, the data passed by the app is converted to\na JSON representation and the error will be returned by the API when it is called.\n\nGenerally the functions take required parameters separately from any optional arguments. The\noptional arguments are passed as a Map (with a defined type).\n\nThe defined types used to pass optional arguments use the standard Elixir snake-case for keys. The\nAPI itself uses camel-case Strings for keys. The library provides the conversion. Most of the API\nkeys use a lower-case letter for the first word and upper-case for the subsequent words. If there\nare exceptions to this rule they are handled by the library so an Elixir developer can just use\nstandard snake-case for all the keys.","ref":"ExAws.Support.html"},{"type":"module","title":"Types of Operations - ExAws.Support","doc":"The API provides two different groups of operations:\n\n- Support case management operations to manage the entire life cycle of your AWS support cases, from creating a case to resolving it\n- AWS Trusted Advisor operations to access AWS Trusted Advisor checks","ref":"ExAws.Support.html#module-types-of-operations"},{"type":"module","title":"Support Case Management - ExAws.Support","doc":"Support Case Management API's provide the following:\n\n- Open a support case\n- Get a list and detailed information about recent support cases\n- Filter your search for support cases by dates and case identifiers, including resolved cases\n- Add communications and file attachments to your cases, and add the email recipients for case\n  correspondences. You can attach up to three files. Each file can be up to 5 MB\n- Resolve your cases","ref":"ExAws.Support.html#module-support-case-management"},{"type":"module","title":"AWS Trusted Advisor - ExAws.Support","doc":"AWS Trusted Advisor API's provide the following:\n\n- Get the names and identifiers for the Trusted Advisor checks\n- Request that a Trusted Advisor check be run against your AWS account and resources\n- Get summaries and detailed information for your Trusted Advisor check results\n- Refresh your Trusted Advisor checks\n- Get the status of each Trusted Advisor check","ref":"ExAws.Support.html#module-aws-trusted-advisor"},{"type":"module","title":"Endpoints - ExAws.Support","doc":"AWS Support is a global service. This means that any endpoint that you use will update your\nsupport cases in the Support Center Console.\n\nFor example, if you use the US East (N. Virginia) endpoint to create a case, you can use the US\nWest (Oregon) or Europe (Ireland) endpoint to add a correspondence to the same case.\n\nYou can use the following endpoints for the AWS Support API:\n\n- US East (N. Virginia) – https://support.us-east-1.amazonaws.com\n- US West (Oregon) – https://support.us-west-2.amazonaws.com\n- Europe (Ireland) – https://support.eu-west-1.amazonaws.com\n\nIf you call the CreateCase operation to create test support cases, then AWS recommends that you\ninclude a subject line, such as TEST CASE-Please ignore. After you're done with your test support\ncase, call the `resolve_case/1` operation to resolve it.\n\nTo call the AWS Trusted Advisor operations in the AWS Support API, you must use the US East (N.\nVirginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support\nthe Trusted Advisor operations.","ref":"ExAws.Support.html#module-endpoints"},{"type":"module","title":"Notes - ExAws.Support","doc":"There is a lack of clarity in the doc on the format for `after_time` and `before_time`. Most\nlikely an ISO8601 String works. I've seen random examples on the web using the YYYY-MM-DDTHH:MM\nformat (for example, \"2024-07-19T16:40\").\n\nYou must have a Business, Enterprise On-Ramp, or Enterprise Support plan to use the AWS Support\nAPI.\n\nIf you call the AWS Support API from an account that doesn't have a Business, Enterprise On-Ramp,\nor Enterprise Support plan, the SubscriptionRequiredException error message appears. For\ninformation about changing your support plan, see [AWS\nSupport](http://aws.amazon.com/premiumsupport/).","ref":"ExAws.Support.html#module-notes"},{"type":"function","title":"ExAws.Support.add_attachments_to_set/2","doc":"Adds one or more attachments to an attachment set","ref":"ExAws.Support.html#add_attachments_to_set/2"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.add_attachments_to_set/2","doc":"* attachments - One or more attachments to add to the set\n* attachment_set_id - The ID of the attachment set (to add the attachments to). If nil is provided\n  for this then a new attachment set is created","ref":"ExAws.Support.html#add_attachments_to_set/2-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.add_attachments_to_set/2","doc":"If an attachment_set_id is not specified, a new attachment set is created, and the ID of the set\nis returned in the response. If an attachment_set_id is specified, the attachments are added to\nthe specified set, if it exists.\n\nAn attachment set is a temporary container for attachments that are to be added to a case or case\ncommunication. The set is available for one hour after it is created; the expiryTime returned in\nthe response indicates when the set expires. The maximum number of attachments in a set is 3, and\nthe maximum size of any attachment in the set is 5 MB.","ref":"ExAws.Support.html#add_attachments_to_set/2-notes"},{"type":"function","title":"Examples - ExAws.Support.add_attachments_to_set/2","doc":"iex> attachment_set_id = \"as-2f5a6faa2a4a1e600-mu-nk5xQlBr70-G1cUos5LZkd38KOAHZa9BMDVzNEXAMPLE\"\n    iex> data = Base.encode64(\"This is a test\")\n    iex> attachments = [%{file_name: \"troubleshoot-screenshot.png\", data: data}]\n    iex> ExAws.Support.add_attachments_to_set(attachments, attachment_set_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"attachmentSetId\" => \"as-2f5a6faa2a4a1e600-mu-nk5xQlBr70-G1cUos5LZkd38KOAHZa9BMDVzNEXAMPLE\",\n        \"attachments\" => [\n          %{\n            \"data\" => \"VGhpcyBpcyBhIHRlc3Q=\",\n            \"fileName\" => \"troubleshoot-screenshot.png\"\n          }\n        ]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.AddAttachmentsToSet\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }\n\n    iex> file1 = \"MyTest.txt\"\n    iex> data1 = Base.encode64(\"This is MyTest.txt contents\")\n    iex> file2 = \"OtherFile.txt\"\n    iex> data2 = Base.encode64(\"This is OtherFile.txt contents\")\n    iex> attachments = [[data: data1, file_name: file1], [data: data2, file_name: file2]]\n    iex> ExAws.Support.add_attachments_to_set(attachments)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"attachments\" => [\n          %{\n            \"data\" => \"VGhpcyBpcyBNeVRlc3QudHh0IGNvbnRlbnRz\",\n            \"fileName\" => \"MyTest.txt\"\n          },\n          %{\n            \"data\" => \"VGhpcyBpcyBPdGhlckZpbGUudHh0IGNvbnRlbnRz\",\n            \"fileName\" => \"OtherFile.txt\"\n          }\n        ]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.AddAttachmentsToSet\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#add_attachments_to_set/2-examples"},{"type":"function","title":"ExAws.Support.add_communication_to_case/4","doc":"Adds additional customer communication to an AWS Support case","ref":"ExAws.Support.html#add_communication_to_case/4"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.add_communication_to_case/4","doc":"* case_id - The AWS Support case ID requested or returned in the call\n  * attachment_set_id - The ID of a set of one or more attachments for\n  the communication to add to the case\n  * communication_body - The body of an email communication to add to the\n  support case\n  * cc_email_addresses - The email addresses in the CC line of an email to be\n  added to the support case","ref":"ExAws.Support.html#add_communication_to_case/4-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.add_communication_to_case/4","doc":"You use the case_id value to identify the case to add communication to. You can list a set of\nemail addresses to copy on the communication using the cc_email_addresses value. The\ncommunication_body value contains the text of the communication.\n\nThe response indicates the success or failure of the request","ref":"ExAws.Support.html#add_communication_to_case/4-notes"},{"type":"function","title":"Examples - ExAws.Support.add_communication_to_case/4","doc":"iex> case_id = \"case-12345678910-2013-c4c1d2bf33c5cf47\"\n    iex> attachment_set_id = \"attachment_set_id\"\n    iex> communication_body = \"Important text\"\n    iex> cc_email_addresses = [\"test@test.com\", \"xyz@test.com\"]\n    iex> ExAws.Support.add_communication_to_case(case_id, attachment_set_id, communication_body, cc_email_addresses)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"attachmentSetId\" => \"attachment_set_id\",\n        \"caseId\" => \"case-12345678910-2013-c4c1d2bf33c5cf47\",\n        \"ccEmailAddresses\" => [\"test@test.com\", \"xyz@test.com\"],\n        \"communicationBody\" => \"Important text\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.AddCommunicationToCase\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#add_communication_to_case/4-examples"},{"type":"function","title":"ExAws.Support.create_case/3","doc":"Creates a new case in the AWS Support Center","ref":"ExAws.Support.html#create_case/3"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.create_case/3","doc":"* subject - The title of the support case\n* communication_body - The communication body text that describes the issue\n* create_case_optional - Optional data used when creating the case","ref":"ExAws.Support.html#create_case/3-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.create_case/3","doc":"This operation is modeled on the behavior of the AWS Support Center Create Case page\n\n* subject - The Subject field on the AWS Support Center Create Case page.\n* communication_body - The Description field on the AWS Support Center Create Case page.\n* create_case_optional - Optional fields\n\nNote: To add additional communication or attachments to an existing case, use\n`add_communication_to_case/4`.\n\nA successful `create_case/3` request returns an AWS Support case number. Case numbers are used by\nthe describe_cases operation to retrieve existing AWS Support cases.","ref":"ExAws.Support.html#create_case/3-notes"},{"type":"function","title":"Examples - ExAws.Support.create_case/3","doc":"iex> subject = \"Question about my account\"\n    iex> communication_body = \"I want to learn more about the AWS XYZZY service.\"\n    iex> ExAws.Support.create_case(subject, communication_body)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"communicationBody\" => \"I want to learn more about the AWS XYZZY service.\",\n        \"subject\" => \"Question about my account\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.CreateCase\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }\n\n    iex> create_case_optional = [\n    ...>      service_code: \"amazon-relational-database-service-mariadb\",\n    ...>      severity_code: \"urgent\",\n    ...>      issue_type: \"technical\",\n    ...>      category_code: \"connectivity\",\n    ...>      language: \"en\"\n    ...> ]\n    iex> subject = \"Problem with our MariaDB\"\n    iex> communication_body = \"Cannot connect to XYZ\"\n    iex> ExAws.Support.create_case(subject, communication_body, create_case_optional)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"categoryCode\" => \"connectivity\",\n        \"communicationBody\" => \"Cannot connect to XYZ\",\n        \"issueType\" => \"technical\",\n        \"language\" => \"en\",\n        \"serviceCode\" => \"amazon-relational-database-service-mariadb\",\n        \"severityCode\" => \"urgent\",\n        \"subject\" => \"Problem with our MariaDB\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.CreateCase\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#create_case/3-examples"},{"type":"function","title":"ExAws.Support.describe_attachment/1","doc":"Returns the attachment that has the specified ID","ref":"ExAws.Support.html#describe_attachment/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_attachment/1","doc":"* attachment_id - The ID of the attachment to return","ref":"ExAws.Support.html#describe_attachment/1-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_attachment/1","doc":"Attachments can include screenshots, error logs, or other files that describe your issue.\nAttachment IDs are generated by the case management system when you add an attachment to a case or\ncase communication. Attachment IDs are returned in the AttachmentDetails objects that are returned\nby the `describe_communications/2` operation.","ref":"ExAws.Support.html#describe_attachment/1-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_attachment/1","doc":"iex> attachment_id = \"attachment-KBnjRNrePd9D6Jx0\"\n    iex> ExAws.Support.describe_attachment(attachment_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"attachmentId\" => \"attachment-KBnjRNrePd9D6Jx0\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeAttachment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_attachment/1-examples"},{"type":"function","title":"ExAws.Support.describe_cases/1","doc":"Returns a list of cases that you specify by passing one or more case IDs","ref":"ExAws.Support.html#describe_cases/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_cases/1","doc":"* describe_cases_optional - Optional fields","ref":"ExAws.Support.html#describe_cases/1-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_cases/1","doc":"Since no arguments are required you can call this API to list all your cases.\n\nIn addition, you can filter the cases by date by setting values for the after_time and before_time\nrequest parameters. You can set values for the include_resolved_cases and include_communications\nrequest parameters to control how much information is returned.\n\nCase data is available for 12 months after creation. If a case was created more than 12 months\nago, a request for data might cause an error.\n\nThe response returns the following in JSON format:\n\n* One or more CaseDetails data types.\n* One or more next_token values, which specify where to paginate the returned records represented\nby the CaseDetails objects.","ref":"ExAws.Support.html#describe_cases/1-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_cases/1","doc":"iex> ExAws.Support.describe_cases()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeCases\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }\n\n    iex> ExAws.Support.describe_cases(after_time: \"2018-12-01T01:00\", include_resolved_cases: true)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"afterTime\" => \"2018-12-01T01:00\", \"includeResolvedCases\" => true},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeCases\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_cases/1-examples"},{"type":"function","title":"ExAws.Support.describe_communications/2","doc":"Returns communications (and attachments) for one or more support cases","ref":"ExAws.Support.html#describe_communications/2"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_communications/2","doc":"* case_id - The support case ID requested or returned in the call\n* describe_communications_optional - optional data","ref":"ExAws.Support.html#describe_communications/2-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_communications/2","doc":"You can use the after_time and before_time parameters to filter by date. You can use the caseId\nparameter to restrict the results to a particular case.\n\nCase data is available for 12 months after creation. If a case was created more than 12 months\nago, a request for data might cause an error.\n\nYou can use the max_results and next_token parameters to control the pagination of the result set.\nSet max_results to the number of cases you want displayed on each page, and use next_token to\nspecify the resumption of pagination.","ref":"ExAws.Support.html#describe_communications/2-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_communications/2","doc":"iex> case_id = \"case-12345678910-2013-c4c1d2bf33c5cf47\"\n    iex> ExAws.Support.describe_communications(case_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"caseId\" => \"case-12345678910-2013-c4c1d2bf33c5cf47\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeCommunications\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }\n\n    iex> describe_communication_optional = %{after_time: \"2018-12-01T01:00\", max_results: 10}\n    iex> case_id = \"case-12345678910-2013-c4c1d2bf33c5cf47\"\n    iex> ExAws.Support.describe_communications(case_id, describe_communication_optional)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"afterTime\" => \"2018-12-01T01:00\",\n        \"caseId\" => \"case-12345678910-2013-c4c1d2bf33c5cf47\",\n        \"maxResults\" => 10\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeCommunications\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_communications/2-examples"},{"type":"function","title":"ExAws.Support.describe_create_case_options/4","doc":"Returns a list of CreateCaseOption types along with the corresponding supported hours and language\navailability","ref":"ExAws.Support.html#describe_create_case_options/4"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_create_case_options/4","doc":"* service_code - The code for the AWS service\n* category_code - The category of problem for the support case.\n* issue_type - The type of issue for the case\n* language - The ISO 639-1 code for the language in which AWS provides support.\nLanguage parameters must be passed explicitly for operations that take them. The\ndefault is \"en\".","ref":"ExAws.Support.html#describe_create_case_options/4-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_create_case_options/4","doc":"You can specify the language categoryCode, issueType and serviceCode used to retrieve the\nCreateCaseOptions.","ref":"ExAws.Support.html#describe_create_case_options/4-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_create_case_options/4","doc":"iex> service_code = \"rds\"\n    iex> issue_type = \"technical\"\n    iex> category_code = \"console\"\n    iex> ExAws.Support.describe_create_case_options(service_code, category_code, issue_type)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"categoryCode\" => \"console\",\n        \"issueType\" => \"technical\",\n        \"language\" => \"en\",\n        \"serviceCode\" => \"rds\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeCreateCaseOptions\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_create_case_options/4-examples"},{"type":"function","title":"ExAws.Support.describe_services/2","doc":"Returns the current list of AWS services and a list of service categories that applies to each one","ref":"ExAws.Support.html#describe_services/2"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_services/2","doc":"* language - The ISO 639-1 code for the language in which AWS provides support.\nLanguage parameters must be passed explicitly for operations that take them. The\ndefault is \"en\".\n* service_code_list - list of service codes available for AWS services","ref":"ExAws.Support.html#describe_services/2-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_services/2","doc":"You then use service names and categories in your create_case requests. Each AWS service has its\nown set of categories.\n\nThe service codes and category codes correspond to the values that are displayed in the Service\nand Category drop-down lists on the AWS Support Center Create Case page. The values in those\nfields, however, do not necessarily match the service codes and categories returned by the\n`describe_services/2` request. Always use the service codes and categories obtained\nprogrammatically. This practice ensures that you always have the most recent set of service and\ncategory codes.","ref":"ExAws.Support.html#describe_services/2-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_services/2","doc":"iex> ExAws.Support.describe_services()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"language\" => \"en\", \"serviceCodeList\" => []},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeServices\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_services/2-examples"},{"type":"function","title":"ExAws.Support.describe_severity_levels/1","doc":"Returns the list of severity levels that you can assign to an AWS Support case","ref":"ExAws.Support.html#describe_severity_levels/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_severity_levels/1","doc":"* language - The ISO 639-1 code for the language in which AWS provides support. Language\n  parameters must be passed explicitly for operations that take them. The default is \"en\".","ref":"ExAws.Support.html#describe_severity_levels/1-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_severity_levels/1","doc":"The severity level for a case is also a field in the CaseDetails data type\nincluded in any `create_case/1` request.","ref":"ExAws.Support.html#describe_severity_levels/1-notes"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_severity_levels/1","doc":"* language - The ISO 639-1 code for the language in which AWS provides support.\nLanguage parameters must be passed explicitly for operations that take them. The\ndefault is \"en\".","ref":"ExAws.Support.html#describe_severity_levels/1-parameter-descriptions"},{"type":"function","title":"Examples - ExAws.Support.describe_severity_levels/1","doc":"iex> ExAws.Support.describe_severity_levels()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"language\" => \"en\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeSeverityLevels\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_severity_levels/1-examples"},{"type":"function","title":"ExAws.Support.describe_supported_languages/3","doc":"Returns a list of supported languages for a specified category_code, issue_type and service_code","ref":"ExAws.Support.html#describe_supported_languages/3"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_supported_languages/3","doc":"* service_code - The code for the AWS service\n* category_code - The category of problem for the support case\n* issue_type - The type of issue for the case","ref":"ExAws.Support.html#describe_supported_languages/3-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_supported_languages/3","doc":"The returned supported languages will include a ISO 639-1 code for the language, and the language display name.","ref":"ExAws.Support.html#describe_supported_languages/3-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_supported_languages/3","doc":"iex> service_code = \"rds\"\n    iex> category_code = \"console\"\n    iex> issue_type = \"technical\"\n    iex> ExAws.Support.describe_supported_languages(service_code, category_code, issue_type)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"categoryCode\" => \"console\",\n        \"issueType\" => \"technical\",\n        \"serviceCode\" => \"rds\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeSupportedLanguages\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_supported_languages/3-examples"},{"type":"function","title":"ExAws.Support.describe_trusted_advisor_check_refresh_statuses/1","doc":"Returns the refresh status of the Trusted Advisor checks that have the\nspecified check IDs","ref":"ExAws.Support.html#describe_trusted_advisor_check_refresh_statuses/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_trusted_advisor_check_refresh_statuses/1","doc":"- check_ids - a list of `t:check_id/0` Strings","ref":"ExAws.Support.html#describe_trusted_advisor_check_refresh_statuses/1-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_trusted_advisor_check_refresh_statuses/1","doc":"Check IDs can be obtained by calling `describe_trusted_advisor_checks/1`.\n\nSome checks are refreshed automatically, and their refresh statuses cannot be retrieved by using\nthis operation. Use of the `describe_trusted_advisor_check_refresh_statuses/1` operation for these\nchecks causes an InvalidParameterValue error.\n\nTo call the AWS Trusted Advisor operations in the AWS Support API, you must use the US East (N.\nVirginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support\nthe Trusted Advisor operations. For more information, see About the AWS Support API in the AWS\nSupport User Guide.","ref":"ExAws.Support.html#describe_trusted_advisor_check_refresh_statuses/1-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_trusted_advisor_check_refresh_statuses/1","doc":"iex> check_ids = [\"Pfx0RwqBli\"]\n    iex> ExAws.Support.describe_trusted_advisor_check_refresh_statuses(check_ids)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"checkIds\" => [\"Pfx0RwqBli\"]},\n      params: %{},\n      headers: [\n        {\"x-amz-target\",\n        \"AWSSupport_20130415.DescribeTrustedAdvisorCheckRefreshStatuses\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_trusted_advisor_check_refresh_statuses/1-examples"},{"type":"function","title":"ExAws.Support.describe_trusted_advisor_check_result/2","doc":"Returns the results of the Trusted Advisor check that has the specified check ID","ref":"ExAws.Support.html#describe_trusted_advisor_check_result/2"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_trusted_advisor_check_result/2","doc":"* check_id - The unique identifier for the Trusted Advisor check\n* language - The ISO 639-1 code for the language in which AWS provides support.\nLanguage parameters must be passed explicitly for operations that take them. The\ndefault is \"en\".","ref":"ExAws.Support.html#describe_trusted_advisor_check_result/2-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_trusted_advisor_check_result/2","doc":"Check IDs can be obtained by calling DescribeTrustedAdvisorChecks.\n\nThe response contains a TrustedAdvisorCheckResult object, which contains these three objects:\n\n  * TrustedAdvisorCategorySpecificSummary\n  * TrustedAdvisorResourceDetail\n  * TrustedAdvisorResourcesSummary\n\nIn addition, the response contains these fields:\n\n  * status. The alert status of the check: \"ok\" (green), \"warning\" (yellow), \"error\" (red), or\n    \"not_available\".\n  * timestamp. The time of the last refresh of the check.\n  * checkId. The unique identifier for the check.","ref":"ExAws.Support.html#describe_trusted_advisor_check_result/2-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_trusted_advisor_check_result/2","doc":"iex> check_id = \"Pfx0RwqBli\"\n    iex> ExAws.Support.describe_trusted_advisor_check_result(check_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"checkId\" => \"Pfx0RwqBli\", \"language\" => \"en\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeTrustedAdvisorCheckResult\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_trusted_advisor_check_result/2-examples"},{"type":"function","title":"ExAws.Support.describe_trusted_advisor_check_summaries/1","doc":"Returns the summaries of the results of the Trusted Advisor checks that have the specified check\nIDs","ref":"ExAws.Support.html#describe_trusted_advisor_check_summaries/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_trusted_advisor_check_summaries/1","doc":"- check_ids - a list of `t:check_id/0` Strings","ref":"ExAws.Support.html#describe_trusted_advisor_check_summaries/1-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_trusted_advisor_check_summaries/1","doc":"check_ids can be obtained by calling `describe_trusted_advisor_checks/1`.\n\nThe response contains an array of TrustedAdvisorCheckSummary objects.\n\nThe names and descriptions for Trusted Advisor checks are subject to change. We recommend that you\nspecify the check ID in your code to uniquely identify a check.\n\nTo call the AWS Trusted Advisor operations in the AWS Support API, you must use the US East (N.\nVirginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support\nthe Trusted Advisor operations. For more information, see [About the AWS Support\nAPI](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint) in the\nAWS Support User Guide.","ref":"ExAws.Support.html#describe_trusted_advisor_check_summaries/1-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_trusted_advisor_check_summaries/1","doc":"iex> check_ids = [\"Pfx0RwqBli\", \"Tzz9913B7d\"]\n    iex> ExAws.Support.describe_trusted_advisor_check_summaries(check_ids)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"checkIds\" => [\"Pfx0RwqBli\", \"Tzz9913B7d\"]},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeTrustedAdvisorCheckSummaries\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_trusted_advisor_check_summaries/1-examples"},{"type":"function","title":"ExAws.Support.describe_trusted_advisor_checks/1","doc":"Returns information about all available Trusted Advisor checks, including name, ID, category,\ndescription, and metadata","ref":"ExAws.Support.html#describe_trusted_advisor_checks/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.describe_trusted_advisor_checks/1","doc":"* language - The ISO 639-1 code for the language in which AWS provides support.\nLanguage parameters must be passed explicitly for operations that take them. The\ndefault is \"en\".","ref":"ExAws.Support.html#describe_trusted_advisor_checks/1-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.describe_trusted_advisor_checks/1","doc":"You must specify a language code; English (\"en\") and Japanese (\"ja\") are currently supported. The\nresponse contains a TrustedAdvisorCheckDescription for each check.\n\nThe names and descriptions for Trusted Advisor checks are subject to change. We recommend that you\nspecify the check ID in your code to uniquely identify a check.\n\nTo call the AWS Trusted Advisor operations in the AWS Support API, you must use the US East (N.\nVirginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support\nthe Trusted Advisor operations. For more information, see [About the AWS Support\nAPI](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint) in the\nAWS Support User Guide.","ref":"ExAws.Support.html#describe_trusted_advisor_checks/1-notes"},{"type":"function","title":"Examples - ExAws.Support.describe_trusted_advisor_checks/1","doc":"iex> ExAws.Support.describe_trusted_advisor_checks()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"language\" => \"en\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.DescribeTrustedAdvisorChecks\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#describe_trusted_advisor_checks/1-examples"},{"type":"function","title":"ExAws.Support.refresh_trusted_advisor_check/1","doc":"Requests a refresh of the Trusted Advisor check that has the specified check_id","ref":"ExAws.Support.html#refresh_trusted_advisor_check/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.refresh_trusted_advisor_check/1","doc":"- check_id - The unique identifier for the Trusted Advisor check","ref":"ExAws.Support.html#refresh_trusted_advisor_check/1-parameter-descriptions"},{"type":"function","title":"Notes - ExAws.Support.refresh_trusted_advisor_check/1","doc":"Check IDs can be obtained by calling `describe_trusted_advisor_checks/1`\n\nSome checks are refreshed automatically, and they cannot be refreshed by using this operation. Use\nof the `refresh_trusted_advisor_check/1` function for these checks causes an InvalidParameterValue\nerror.\n\nThe names and descriptions for Trusted Advisor checks are subject to change. We recommend that you\nspecify the check ID in your code to uniquely identify a check.\n\nTo call the AWS Trusted Advisor operations in the AWS Support API, you must use the US East (N.\nVirginia) endpoint. Currently, the US West (Oregon) and Europe (Ireland) endpoints don't support\nthe Trusted Advisor operations. For more information, see [About the AWS Support\nAPI](https://docs.aws.amazon.com/awssupport/latest/user/about-support-api.html#endpoint) in the\nAWS Support User Guide.","ref":"ExAws.Support.html#refresh_trusted_advisor_check/1-notes"},{"type":"function","title":"Examples - ExAws.Support.refresh_trusted_advisor_check/1","doc":"iex> check_id = \"Pfx0RwqBli\"\n    iex> ExAws.Support.refresh_trusted_advisor_check(check_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"checkId\" => \"Pfx0RwqBli\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.RefreshTrustedAdvisorCheck\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#refresh_trusted_advisor_check/1-examples"},{"type":"function","title":"ExAws.Support.resolve_case/1","doc":"Takes a case_id and returns the initial state of the case along with the state of the case after\nthe call to resolve_case completed","ref":"ExAws.Support.html#resolve_case/1"},{"type":"function","title":"Parameter Descriptions - ExAws.Support.resolve_case/1","doc":"- case_id - The AWS Support case id that you are resolving","ref":"ExAws.Support.html#resolve_case/1-parameter-descriptions"},{"type":"function","title":"Examples - ExAws.Support.resolve_case/1","doc":"iex> case_id = \"case-12345678910-2013-c4c1d2bf33c5cf47\"\n    iex> ExAws.Support.resolve_case(case_id)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"caseId\" => \"case-12345678910-2013-c4c1d2bf33c5cf47\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"AWSSupport_20130415.ResolveCase\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :support,\n      before_request: nil\n    }","ref":"ExAws.Support.html#resolve_case/1-examples"},{"type":"type","title":"ExAws.Support.after_time/0","doc":"The start date for a filtered date search on support case communications","ref":"ExAws.Support.html#t:after_time/0"},{"type":"type","title":"Notes - ExAws.Support.after_time/0","doc":"Case communications are available for 12 months after creation. String format is not well defined\nin the AWS doc. However, the format YYYY-MM-DDTHH:MM (for example: \"2018-12-19T16:40\") seems to\nappear in some examples.","ref":"ExAws.Support.html#t:after_time/0-notes"},{"type":"type","title":"ExAws.Support.attachment/0","doc":"An attachment to a case communication\n\nThe attachment consists of the file name and the content of the file. Each attachment file size\nshould not exceed 5 MB. File types that are supported include the following:\npdf, jpeg, doc, log, text\n\n- data - attachment file contents, base64 encoded binary data object (see `Base.encode64/1`).\n- file_name - attachment filename","ref":"ExAws.Support.html#t:attachment/0"},{"type":"type","title":"ExAws.Support.attachment_id/0","doc":"Attachment IDs are generated by the case management system when you\nadd an attachment to a case or case communication\n\nAttachment IDs are returned in the AttachmentDetails objects that are returned by the\n`describe_communications/2` operation","ref":"ExAws.Support.html#t:attachment_id/0"},{"type":"type","title":"ExAws.Support.attachment_set_id/0","doc":"The ID of the attachment set","ref":"ExAws.Support.html#t:attachment_set_id/0"},{"type":"type","title":"Notes - ExAws.Support.attachment_set_id/0","doc":"If an attachment_set_id is not specified, a new attachment set is created, and the ID of the set is\nreturned in the response. If an attachment_set_id is specified, the attachments are added to the\nspecified set, if it exists.","ref":"ExAws.Support.html#t:attachment_set_id/0-notes"},{"type":"type","title":"ExAws.Support.attachments/0","doc":"List of `t:attachment/0`","ref":"ExAws.Support.html#t:attachments/0"},{"type":"type","title":"ExAws.Support.before_time/0","doc":"The end date for a filtered date search on support case communications","ref":"ExAws.Support.html#t:before_time/0"},{"type":"type","title":"Notes - ExAws.Support.before_time/0","doc":"Case communications are available for 12 months after creation. String format is not well defined\nin the AWS doc. However, the format YYYY-MM-DDTHH:MM (for example: \"2018-12-19T16:40\") seems to\nappear in some examples.","ref":"ExAws.Support.html#t:before_time/0-notes"},{"type":"type","title":"ExAws.Support.case_id/0","doc":"The support case ID","ref":"ExAws.Support.html#t:case_id/0"},{"type":"type","title":"Notes - ExAws.Support.case_id/0","doc":"The case ID is an alphanumeric string in the following format: case-12345678910-2013-c4c1d2bf33c5cf47","ref":"ExAws.Support.html#t:case_id/0-notes"},{"type":"type","title":"ExAws.Support.category_code/0","doc":"The category of problem for the support case","ref":"ExAws.Support.html#t:category_code/0"},{"type":"type","title":"Notes - ExAws.Support.category_code/0","doc":"You can use the `describe_services/2` operation to get the category code for a service. Each AWS\nservice defines its own set of category codes.","ref":"ExAws.Support.html#t:category_code/0-notes"},{"type":"type","title":"ExAws.Support.cc_email_addresses/0","doc":"The email addresses in the CC line of an email to be added to the support case.\n\n- Minimum number of 0 items. Maximum number of 10 items.","ref":"ExAws.Support.html#t:cc_email_addresses/0"},{"type":"type","title":"ExAws.Support.check_id/0","doc":"The unique identifier for the Trusted Advisor check","ref":"ExAws.Support.html#t:check_id/0"},{"type":"type","title":"ExAws.Support.communication_body/0","doc":"The body of an email communication to add to the support case.\n\n- Length Constraints: Minimum length of 1. Maximum length of 8000.","ref":"ExAws.Support.html#t:communication_body/0"},{"type":"type","title":"ExAws.Support.create_case_optional/0","doc":"Optional input for function `create_case/4`\n\n- `attachment_set_id` - The ID of a set of attachments that has been created by\nusing `add_attachments_to_set/2`\n- `category_code` - The category for the service defined for the `service_code`\nvalue. You also get the category code for a service by calling `describe_services/2`.\nEach AWS service defines its own set of category codes.\n- `cc_email_addresses` - The AWS Support Center CC field on the Create Case\npage. You can list email addresses to be copied on any correspondence about the\ncase. The account that opens the case is already identified by passing the\nAWS Credentials in the HTTP POST method or in a method or function call from\none of the programming languages supported by an AWS SDK.\n- `issue_type` - The type of issue for the case. You can specify either\n\"customer-service\" or \"technical.\" If you do not indicate a value, the\ndefault is \"technical.\" Note: Service limit increases are not supported\nby the Support API; you must submit service limit increase requests in\nSupport Center.\n- `language` - The human language in which AWS Support handles the case.\nEnglish and Japanese are currently supported.\n- `service_code` - The code for an AWS service. You can get the possible values by calling\n`describe_services/2`.\n- `severity_code` - A value that indicates the urgency of the case, which in turn determines the\nresponse time according to your service level agreement with AWS Support. You can get the possible\nseverity code values by calling `describe_severity_levels/1`. For more information about the\nmeaning of the codes, see\n[SeverityLevel](https://docs.aws.amazon.com/awssupport/latest/APIReference/API_SeverityLevel.html)\nand [Choosing a\nSeverity](https://docs.aws.amazon.com/awssupport/latest/user/getting-started.html#choosing-severity)\nin the _AWS Support User Guide_.","ref":"ExAws.Support.html#t:create_case_optional/0"},{"type":"type","title":"ExAws.Support.describe_cases_optional/0","doc":"Optional input to the function `describe_cases/1`\n\n- after_time - The start date for a filtered date search on support case communications\n- before_time - The end date for a filtered date search on support case communications\n- case_id_list - A list of ID numbers of the support cases you want returned. The maximum number\nof cases is 100. Note: A case_id in AWS is not the value that you see in AWS Support web pages.\nThat is the display_id. Its a unique identifier returned when you create a case that includes your\naccount id. The case ID is an alphanumeric string formatted as shown in this example:\n\"case-12345678910-2013-c4c1d2bf33c5cf47\"\n- display_id - This is the 10 digit number shown in the AWS Support web interface and labeled\n\"Case Id\"\n- include_resolved_cases - Specifies whether resolved support cases should be included in the\n`describe_cases/1` results. The default is false. If you are not getting data back and you expect\nto, ensure that you are setting this to true.\n* language - The ISO 639-1 code for the language in which AWS provides support.\nLanguage parameters must be passed explicitly for operations that take them. The\ndefault is \"en\".\n- max_results: The maximum number of results to return before paginating\n- next_token: A resumption point for pagination","ref":"ExAws.Support.html#t:describe_cases_optional/0"},{"type":"type","title":"ExAws.Support.describe_communications_optional/0","doc":"Optional input to the `describe_communications/2` function\n\n- after_time - The start date for a filtered date search on support case communications.\nCase communications are available for 12 months after creation. String format is:\nYYYY-MM-DDTHH:MM, for example: 2018-12-19T16:40\"\n- before_time - The end date for a filtered date search on support case communications.\nCase communications are available for 12 months after creation.\n- max_results - The maximum number of results to return before paginating. Integer.\nValid Range: Minimum value of 10. Maximum value of 100.\n- next_token - A resumption point for pagination","ref":"ExAws.Support.html#t:describe_communications_optional/0"},{"type":"type","title":"ExAws.Support.display_id/0","doc":"The ID displayed for a case in the AWS Support Center user interface","ref":"ExAws.Support.html#t:display_id/0"},{"type":"type","title":"ExAws.Support.issue_type/0","doc":"The type of issue for the case","ref":"ExAws.Support.html#t:issue_type/0"},{"type":"type","title":"Notes - ExAws.Support.issue_type/0","doc":"If you don't specify a value, the default is \"technical\".","ref":"ExAws.Support.html#t:issue_type/0-notes"},{"type":"type","title":"Valid Values - ExAws.Support.issue_type/0","doc":"```\n[\"customer-service\", \"technical\"]\n```","ref":"ExAws.Support.html#t:issue_type/0-valid-values"},{"type":"type","title":"ExAws.Support.language/0","doc":"The language in which AWS Support handles the case","ref":"ExAws.Support.html#t:language/0"},{"type":"type","title":"Notes - ExAws.Support.language/0","doc":"AWS Support currently supports Chinese (“zh”), English (\"en\"), Japanese (\"ja\") and Korean (“ko”).\nYou must specify the ISO 639-1 code for the language parameter if you want support in that\nlanguage.","ref":"ExAws.Support.html#t:language/0-notes"},{"type":"type","title":"ExAws.Support.max_results/0","doc":"The maximum number of results to return before paginating\n\n- Valid Range: Minimum value of 10. Maximum value of 100.","ref":"ExAws.Support.html#t:max_results/0"},{"type":"type","title":"ExAws.Support.next_token/0","doc":"A resumption point for pagination\n\nReturned by previous call as \"nextToken\" in the JSON.","ref":"ExAws.Support.html#t:next_token/0"},{"type":"type","title":"ExAws.Support.service_code/0","doc":"The code for the AWS service","ref":"ExAws.Support.html#t:service_code/0"},{"type":"type","title":"Notes - ExAws.Support.service_code/0","doc":"You can use the `describe_services/2` function to get the possible service_code values.","ref":"ExAws.Support.html#t:service_code/0-notes"},{"type":"type","title":"ExAws.Support.severity_code/0","doc":"A value that indicates the urgency of the case","ref":"ExAws.Support.html#t:severity_code/0"},{"type":"type","title":"Notes - ExAws.Support.severity_code/0","doc":"This value determines the response time according to your service level agreement with AWS\nSupport. You can use the `describe_severity_levels/1` operation to get the possible values for\nseverity_code.\n\nFor more information, see\n[SeverityLevel](https://docs.aws.amazon.com/awssupport/latest/APIReference/API_SeverityLevel.html)\nand [Choosing a\nSeverity](https://docs.aws.amazon.com/awssupport/latest/user/getting-started.html#choosing-severity)\nin the AWS Support User Guide.\n\nNote: The availability of severity levels depends on the support plan for the AWS account.","ref":"ExAws.Support.html#t:severity_code/0-notes"},{"type":"type","title":"ExAws.Support.subject/0","doc":"The title of the support case\n\nThe title appears in the Subject field on the AWS Support Center [Create\nCase](https://console.aws.amazon.com/support/home#/case/create) page.","ref":"ExAws.Support.html#t:subject/0"},{"type":"module","title":"ExAws.Support.Utils","doc":"Helper utility functions","ref":"ExAws.Support.Utils.html"},{"type":"function","title":"ExAws.Support.Utils.camelize/2","doc":"Camelize an atom or string value\n\nThis works as expected if the val uses an underscore or\nhyphen to separate words. This only works for atoms and\nstrings. Passing another value type (integer, list, map)\nwill raise exception.\n\nThe regex used to split a String into words is: `~r/(?:^|[-_])|(?=[A-Z])/`","ref":"ExAws.Support.Utils.html#camelize/2"},{"type":"function","title":"Example - ExAws.Support.Utils.camelize/2","doc":"iex> ExAws.CodePipeline.Utils.camelize(:test_val)\n    \"testVal\"\n\n    iex> ExAws.CodePipeline.Utils.camelize(:\"test_val\")\n    \"testVal\"\n\n    iex> ExAws.CodePipeline.Utils.camelize(:\"abc-def-a123\")\n    \"abcDefA123\"\n\n    iex> ExAws.CodePipeline.Utils.camelize(:A_test_of_initial_cap)\n    \"aTestOfInitialCap\"","ref":"ExAws.Support.Utils.html#camelize/2-example"},{"type":"function","title":"ExAws.Support.Utils.camelize_map/2","doc":"Camelize keys, including traversing values that are also Maps.\n\nThe caller can pass in an argument to indicate whether the first letter of a key for the map are\ndowncased or capitalized.\n\nKeys should be atoms and follow the rules listed for the `camelize/2` function.","ref":"ExAws.Support.Utils.html#camelize_map/2"},{"type":"function","title":"Example - ExAws.Support.Utils.camelize_map/2","doc":"iex> val = %{abc_def: 123, another_val: \"val2\"}\n    iex> ExAws.CodePipeline.Utils.camelize_map(val)\n    %{\"abcDef\" => 123, \"anotherVal\" => \"val2\"}\n\n    iex> val = %{abc_def: 123, another_val: %{embed_value: \"val2\"}}\n    iex> ExAws.CodePipeline.Utils.camelize_map(val)\n    %{\"abcDef\" => 123, \"anotherVal\" => %{\"embedValue\" => \"val2\"}}\n\n    iex> val = %{abc_def: 123, another_val: %{embed_value: \"val2\"}}\n    iex> ExAws.CodePipeline.Utils.camelize_map(val, %{subkeys: %{}, keys: %{}, default: :upper})\n    %{\"AbcDef\" => 123, \"AnotherVal\" => %{\"EmbedValue\" => \"val2\"}}","ref":"ExAws.Support.Utils.html#camelize_map/2-example"},{"type":"function","title":"ExAws.Support.Utils.camelize_rules/0","doc":"Return the default camelize rules\n\nA caller can override this by creating a `t:camelize_rules/0` and passing\nit into functions instead of the default.","ref":"ExAws.Support.Utils.html#camelize_rules/0"},{"type":"function","title":"ExAws.Support.Utils.keyword_to_map/1","doc":"If val is a Keyword then convert to a Map, else return val.\n\nThis function works recursively. If you have a Keyword list where\nthe value for the key is a keyword then the val is converted to\na Map as well.","ref":"ExAws.Support.Utils.html#keyword_to_map/1"},{"type":"function","title":"Examples - ExAws.Support.Utils.keyword_to_map/1","doc":"iex> ExAws.CodePipeline.Utils.keyword_to_map([{:a, 7}, {:b, \"abc\"}])\n    %{a: 7, b: \"abc\"}\n\n    iex> ExAws.CodePipeline.Utils.keyword_to_map(%{a: 7, b: %{c: \"abc\"}})\n    %{a: 7, b: %{c: \"abc\"}}\n\n    iex> ExAws.CodePipeline.Utils.keyword_to_map([1, 2, 3])\n    [1, 2, 3]\n\n    iex> ExAws.CodePipeline.Utils.keyword_to_map[test: [inner: \"abc\"]]\n    %{test: %{inner: \"abc\"}}","ref":"ExAws.Support.Utils.html#keyword_to_map/1-examples"},{"type":"function","title":"ExAws.Support.Utils.string_camelize/2","doc":"","ref":"ExAws.Support.Utils.html#string_camelize/2"},{"type":"type","title":"ExAws.Support.Utils.camelization/0","doc":"Approach to camelization\n\n- upper - all words are upper-cased\n- lower - the first word is lower cased and the remaining words are upper-cased","ref":"ExAws.Support.Utils.html#t:camelization/0"},{"type":"type","title":"Examples - ExAws.Support.Utils.camelization/0","doc":"<!-- tabs-open -->\n\n### :upper\n\n```\niex> camelize_rules = %{default: :upper}\niex> ExAws.CodePipeline.Utils.camelize(:test_things, camelize_rules)\n\"TestThings\"\n\niex> camelize_rules = %{default: :upper}\niex> ExAws.CodePipeline.Utils.camelize(:abc, camelize_rules)\n\"Abc\"\n\niex> camelize_rules = %{default: :upper}\niex> ExAws.CodePipeline.Utils.camelize(\"test-a-string\", camelize_rules)\n\"TestAString\"\n```\n\n### :lower\n\n```\niex> camelize_rules = %{default: :lower}\niex> ExAws.CodePipeline.Utils.camelize(:test_things, camelize_rules)\n\"testThings\"\n\niex> camelize_rules = %{default: :lower}\niex> ExAws.CodePipeline.Utils.camelize(:abc, camelize_rules)\n\"abc\"\n\niex> camelize_rules = %{default: :lower}\niex> ExAws.CodePipeline.Utils.camelize(\"test-a-string\", camelize_rules)\n\"testAString\"\n```\n<!-- tabs-close -->","ref":"ExAws.Support.Utils.html#t:camelization/0-examples"},{"type":"type","title":"ExAws.Support.Utils.camelize_rules/0","doc":"The camelize, camelize_list, and camelize_map take an argument that is\na data structure providing rules for capitalization.\n\n- subkeys - this provides a map that indicates how keys found under this\n  particular key should be camelized\n- keys - this provides a map that indicate how particular keys should be\n  camelized\n- default - indicates whether `:upper` or `:lower` is used by default","ref":"ExAws.Support.Utils.html#t:camelize_rules/0"},{"type":"extras","title":"AWS Support API","doc":"# AWS Support API\n\nAWS Support Service module for [ex_aws](https://github.com/ex-aws/ex_aws)","ref":"readme.html"},{"type":"extras","title":"Installation - AWS Support API","doc":"The package can be installed by adding ex_aws_support to your list of dependencies in mix.exs along with :ex_aws and your preferred JSON codec / http client. Example:\n\n```elixir\ndef deps do\n  [\n    {:ex_aws, \"~> 2.0\"},\n    {:ex_aws_support, \"~> 2.1\"},\n    {:poison, \"~> 3.0\"},\n    {:hackney, \"~> 1.9\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - AWS Support API","doc":"* [ex_aws](https://hexdocs.pm/ex_aws)\n* [AWS Support API](https://docs.aws.amazon.com/awssupport/latest/APIReference/Welcome.html)\n* [Go API for AWS Support API](https://github.com/aws/aws-sdk-go/blob/master/models/apis/support/2013-04-15/api-2.json)","ref":"readme.html#documentation"},{"type":"extras","title":"License - AWS Support API","doc":"[License](LICENSE)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"v2.1.0\n------\n#### Enhancements\n  - Added CHANGELOG.md\n  - Use Github Workflows to test with multiple Elixir versions, credo, dialyzer\n  - Update dependencies\n  - More doctests","ref":"changelog.html"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2019 Vonage, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}